pub struct Name(/* private fields */);Trait Implementations
impl Copy for Name
Sourceimpl Encode for Name
impl Encode for Name
Sourcefn encoded_len(&self) -> Result<usize, Error>
fn encoded_len(&self) -> Result<usize, Error>
Get the length of this type encoded in bytes, prior to Base64 encoding. Read more
Sourcefn encoded_len_prefixed(&self) -> Result<usize, Error>
fn encoded_len_prefixed(&self) -> Result<usize, Error>
Return the length of this type after encoding when prepended with a
uint32 length prefix. Read moreimpl Eq for Name
impl StructuralPartialEq for Name